# Randon

Developed by Roop Majumder from Technical Earth (c) 2020

## Examples of How To Use

using intrand

```python
from randon import intrand

intrand()
```

using floatrand

```python
from randon import floatrand

floatrand()
```

using odd

```python
from randon import odd

odd()
```

using even

```python
from randon import even

even()
```

using guess_the_number

```python
from randon import guess_the_number

guess_the_number()
```
	
##### There are more to explore stay around

##### to learn about randon go to the documentation.